<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 03/05/2010 *
 * ===================                          Last change: 03/05/2010 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : resolver.class.php                               *
 * -------------------------------------------------------------------- *
 * Short description : Resolver class                                   *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Resolver-Klasse                                  *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009, 2010 by Mailer Developer Team                    *
 * For more information visit: http://www.mxchange.org                  *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if (!defined('__SECURITY')) {
	die();
} // END - if

// Resolver class for cached hostname -> IP address resolving
class HostnameResolver {
	// Resolve hostname -> IP address
	function resolveHostname ($hostname) {
		// If sql_patches is not at least 0.7.0, abort here and return the hostname (gethostbyname() may return something unwanted)
		if (!isExtensionInstalledAndNewer('sql_patches', '0.7.0')) {
			// Abort here
			return $hostname;
		} // END - if

		// Prepare hostname, look for the ':port' part
		$hostArray = explode(':', $hostname, 2);
		$hostname = strtolower($hostArray[0]);

		// Is the hostname an IP address?
		if (preg_match('/(25[0-5]|2[0-4][0-9]|[0-1]{1}[0-9]{2}|[1-9]{1}[0-9]{1}|[1-9])\.(25[0-5]|2[0-4][0-9]|[0-1]{1}[0-9]{2}|[1-9]{1}[0-9]{1}|[1-9]|0)\.(25[0-5]|2[0-4][0-9]|[0-1]{1}[0-9]{2}|[1-9]{1}[0-9]{1}|[1-9]|0)\.(25[0-5]|2[0-4][0-9]|[0-1]{1}[0-9]{2}|[1-9]{1}[0-9]{1}|[0-9])/', $hostname, $matches)) {
			// Then we don't need to look it up
			//* DEBUG: */ logDebugMessage(__METHOD__, __LINE__, sprintf("Hostname %s is an IP address. No need to lookup.", $hostname));
			return $hostname;
		} // END - if

		// Log entry
		//* DEBUG: */ logDebugMessage(__METHOD__, __LINE__, sprintf("Begin lookup: %s", $hostname));
		$ret = '0.0.0.0';

		// Search for hostname in cache
		$result = SQL_QUERY_ESC("SELECT `ip` FROM `{?_MYSQL_PREFIX?}_dns_cache` WHERE `hostname`='%s' LIMIT 1",
			array($hostname), __METHOD__, __LINE__);

		// Does an entry exist?
		if (SQL_NUMROWS($result) == 1) {
			// Then load the hostname
			list($ip) = SQL_FETCHROW($result);

			// Count cache hit
			incrementStatsEntry('dns_cache_hits');

			// Set fetched IP number as return value
			$ret = $ip;
			//* DEBUG: */ logDebugMessage(__METHOD__, __LINE__, sprintf("Cache used: %s->%s", $hostname, $ip));
		} else {
			// Get IP address
			$ip = gethostbyname($hostname);

			// Count lookup hit
			incrementStatsEntry('dns_lookup_hits');

			// Is it an IP address?
			if (($ip != $hostname) && (preg_match('/(25[0-5]|2[0-4][0-9]|[0-1]{1}[0-9]{2}|[1-9]{1}[0-9]{1}|[1-9])\.(25[0-5]|2[0-4][0-9]|[0-1]{1}[0-9]{2}|[1-9]{1}[0-9]{1}|[1-9]|0)\.(25[0-5]|2[0-4][0-9]|[0-1]{1}[0-9]{2}|[1-9]{1}[0-9]{1}|[1-9]|0)\.(25[0-5]|2[0-4][0-9]|[0-1]{1}[0-9]{2}|[1-9]{1}[0-9]{1}|[0-9])/', $ip, $matches))) {
				// Seems to be an IP! Now check deeper...
				if (($matches[0] == $ip) && ($matches[1] >= 0) && ($matches[1] <= 255) && ($matches[2] >= 0) && ($matches[2] <= 255) && ($matches[3] >= 0) && ($matches[3] <= 255) && ($matches[4] > 0) && ($matches[4] < 255)) {
					// We also cache IP addresses
					SQL_QUERY_ESC("INSERT INTO `{?_MYSQL_PREFIX?}_dns_cache` (`ip`, `hostname`, `added`) VALUES('%s', '%s', NOW())",
						array($ip, $hostname), __METHOD__, __LINE__);

					// Set return value to $ip
					//* DEBUG: */ logDebugMessage(__METHOD__, __LINE__, sprintf("IP detected, cache entry written: %s->%s", $hostname, $ip));
				} else {
					// Network address or broadcast address found
					//* DEBUG: */ logDebugMessage(__METHOD__, __LINE__, sprintf("IP %s is possibly a network or broadcast address.", $ip));
				}
			} elseif ($ip == $hostname) {
				// Nothing found, maybe invalid!
				//* DEBUG: */ logDebugMessage(__METHOD__, __LINE__, sprintf("Cannot lookup: %s", $hostname));
			} else {
				// Put entry in DB
				SQL_QUERY_ESC("INSERT INTO `{?_MYSQL_PREFIX?}_dns_cache` (`ip`, `hostname`, `added`) VALUES('%s', '%s', NOW())",
					array($ip, $hostname), __METHOD__, __LINE__);

				// Set return value to $ip
				$ret = $ip;
				//* DEBUG: */ logDebugMessage(__METHOD__, __LINE__, sprintf("Lookup successfull, cache entry written: %s->%s", $hostname, $ip));
			}
		}

		// Free result
		SQL_FREERESULT($result);

		// Return IP number (let's hope it!
		return $ret;
	}

	// Purge old entries
	function purgeEntries() {
		// SQL for cleaning up
		SQL_QUERY('DELETE LOW_PRIORITY FROM `{?_MYSQL_PREFIX?}_dns_cache` WHERE UNIX_TIMESTAMP(`added`) < (UNIX_TIMESTAMP() - {?dns_cache_timeout?})',
			__METHOD__, __LINE__);
	}
}

// [EOF]
?>
