<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 09/09/2008 *
 * ===================                          Last change: 09/09/2008 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : what-refback.php                                 *
 * -------------------------------------------------------------------- *
 * Short description : Refback setup                                    *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Refback-Einstellungen                            *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009, 2010 by Mailer Developer Team                    *
 * For more information visit: http://www.mxchange.org                  *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if (!defined('__SECURITY')) {
	die();
} elseif (!isMember()) {
	// User is not logged in
	redirectToIndexMemberOnlyModule();
} elseif (!isRefbackEnabled()) {
	// Output message
	loadTemplate('admin_settings_saved', false, '{--MEMBER_REFBACK_DISABLED--}');

	// Abort here
	return false;
} // END - if

// Add description as navigation point
addMenuDescription('member', __FILE__);

if ((!isExtensionActive('refback')) && (!isAdmin())) {
	loadTemplate('admin_settings_saved', false, generateExtensionInactiveNotInstalledMessage('refback'));
	return;
} // END - if

// Was the form submitted?
if ((isFormSent('edit')) && (isPostRequestParameterSet('id'))) {
	// Okay, has the user entered some values?
	if (isPostRequestParameterSet('percents')) {
		// Revert german commta for testing
		$percents = convertCommaToDot(postRequestParameter('percents'));

		// Validate percents
		if ((($percents >= getConfig('refback_min_perc')) || (round($percents) == 0)) && ($percents <= getConfig('refback_max_perc'))) {
			// Change ref-back for this direct id
			$status = updateMemberRefbackPercents(postRequestParameter('id'), postRequestParameter('percents'));

			// Check status
			if (isset($status['ok'])) {
				// No message found
				loadTemplate('admin_settings_saved', false, '{--MEMBER_REFBACK_DONE--}');
			} elseif (isset($status['message'])) {
				// Something went wrong with error message
				loadTemplate('admin_settings_saved', false, getMaskedMessage('MEMBER_REFBACK_ERROR_MESSAGE', $status['message']));
			} else {
				// No message found
				loadTemplate('admin_settings_saved', false, '{--MEMBER_REFBACK_ERROR_EMPTY_MESSAGE--}');
			}
		} else {
			// Percents out-of-bounds ;-)
			loadTemplate('admin_settings_saved', false, getMaskedMessage('MEMBER_REFBACK_ERROR_OUT_OF_BOUNDS'));
		}

		// Insert line
	} else {
		// Read data from refback table
		$content = getArrayFromUserRefbackData(postRequestParameter('id'));

		// Load form for editing
		loadTemplate('member_refback_edit', false, $content);
	}
} // END - if

// Load all referal levels
$result = SQL_QUERY('SELECT
	r.level, r.percents
FROM
	`{?_MYSQL_PREFIX?}_refdepths` AS r
WHERE
	r.level > 0
ORDER BY
	r.level ASC', __FILE__, __LINE__);

// Are there some entries? (Shall be!)
if (!SQL_HASZERONUMS($result)) {
	// List all levels
	$OUT = '';
	while ($content = SQL_FETCHARRAY($result)) {
		// Init variables
		$rows = '';
		$content['counter'] = 0;

		// Check for users ref in this level
		foreach (getArrayFromRefbackUserRefs(getMemberId(), $content['level']) as $refRow) {
			// Not-deleted account is default
			$deleted = false;
			if (is_null($refRow['status'])) $deleted = true;

			// Add/"translate" more content
			// @TODO UNUSED: $refRow['status']      = translateUserStatus($refRow['status']);
			$refRow['joined']      = generateDateTime($refRow['joined'], '3');

			// Load row template
			if ($deleted === true) {
				$rows .= loadTemplate('member_refback_list_row_deleted', true, $refRow);
			} else {
				$rows .= loadTemplate('member_refback_list_row', true, $refRow);
			}

			// Count this ref and switch color
			$content['counter']++;
		} // END - foreach

		// Remember the content
		$content['rows'] = $rows;

		// Load level template
		$OUT .= loadTemplate('member_refback_list_level', true, $content);
	} // END - while

	// Load main template
	loadTemplate('member_refback_list', false, $OUT);
} else {
	// No entries
	loadTemplate('admin_settings_saved', false, '{--MEMBER_REFBACK_NO_ENTRIES--}');
}

// Free result
SQL_FREERESULT($result);

// [EOF]
?>
