<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 04/12/2004 *
 * ===================                          Last change: 11/16/2004 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : what-wernis.php                                  *
 * -------------------------------------------------------------------- *
 * Short description : Wernis requests                                  *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Auszahlungsanfragen                              *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009, 2010 by Mailer Developer Team                    *
 * For more information visit: http://www.mxchange.org                  *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if (!defined('__SECURITY')) {
	die();
} elseif (!isMember()) {
	// User is not logged in
	redirectToIndexMemberOnlyModule();
}

// Add description as navigation point
addMenuDescription('member', __FILE__);

if ((!isExtensionActive('wernis')) && (!isAdmin())) {
	loadTemplate('admin_settings_saved', false, generateExtensionInactiveNotInstalledMessage('wernis'));
	return;
} // END - if

// Check if the admin has entered the data
if ((getConfig('wernis_api_id') == '') || (getConfig('wernis_api_md5') == '')) {
	// Something important is missing...
	loadTemplate('admin_settings_saved', false, '{--MEMBER_WERNIS_API_DATA_MISSING--}');
	return;
} // END - if

// Init the content array and points
$content = array(); $points = false;

// Is the mode set (withdraw or payout)
if ((!isGetRequestParameterSet('mode')) || (getRequestParameter('mode') == 'choose')) {
	// Let the user choose what he wants to do
	$content['wernis_userid'] = '0';

	// Is there an id?
	if ((!empty($content['wernis_userid'])) && (!isGetRequestParameterSet('mode'))) {
		// Then use an other "mode"
		setGetRequestParameter('mode', 'list');

		// And load all rows!
		$result = SQL_QUERY_ESC("SELECT `id`, `wernis_account`, `wernis_amount`, `wernis_timestamp`, `wernis_type` FROM `{?_MYSQL_PREFIX?}_user_wernis` WHERE `userid`=%s ORDER BY `wernis_timestamp` DESC",
			array(getMemberId()), __FILE__, __LINE__);

		// Load all rows
		$content['rows'] = '';
		while ($data = SQL_FETCHARRAY($result)) {
			// Prepare data for output
			$rowContent = array(
				'wernis_timestamp' => generateDateTime($data['wernis_timestamp'], 2),
				'wernis_amount'    => $data['wernis_amount'],
				'wernis_account'   => $data['wernis_account'],
				'wernis_type'      => $data['wernis_type'],
			);

			// Load row template
			$content['rows'] .= loadTemplate('member_wernis_mode_list_row', true, $rowContent);
		} // END - while

		// Free result
		SQL_FREERESULT($result);
	} else {
		// Default links are not active!
		$content['payout_link']   = '<em>{--MEMBER_WERNIS_PAYOUT_DISABLED--}</em>';
		$content['withdraw_link'] = '<em>{--MEMBER_WERNIS_WITHDRAW_DISABLED--}</em>';

		// Is the payout mode active?
		if (getConfig('wernis_payout_active') == 'Y') {
			// Add link
			$content['payout_link'] = '<a class="menu_blur" style="height: 40px" href="{%url=modules.php?module=login&amp;what=wernis&amp;mode=payout%}"><div style="padding-top: 10px">{--MEMBER_WERNIS_MODE_PAYOUT--}</div></a>';
		} // END - if

		// Is the withdraw mode active?
		if (getConfig('wernis_withdraw_active') == 'Y') {
			// Add link
			$content['withdraw_link'] = '<a class="menu_blur" style="height: 40px" href="{%url=modules.php?module=login&amp;what=wernis&amp;mode=withdraw%}"><div style="padding-top: 10px">{--MEMBER_WERNIS_MODE_WITHDRAW--}</div></a>';
		} // END - if

		// Mode chooser! ;-)
		setGetRequestParameter('mode', 'choose');
	}
} elseif ((getRequestParameter('mode') == 'payout') && (getConfig('wernis_payout_active') == 'Y')) {
	// Get user's total points and remove the registration fee
	$points = getTotalPoints(getMemberId()) - getPointsRegister();

	// Is there a percentage or fixed fee?
	$points = WERNIS_TAKE_FEE($points, 'payout');

	// Is this enougth for a payout?
	if ($points < getConfig('wernis_min_payout')) {
		// No, then abort here
		loadTemplate('admin_settings_saved', false, sprintf(
			getMessage('MEMBER_WERNIS_MIN_PAYOUT'),
			translateComma(getConfig('wernis_min_payout')),
			translateComma($points)
		));
		return;
	} // END - if

	// No dots here...
	$points = explode('.', $points);
	$points = bigintval($points[0]);

	// Add points to content array
	$content['points']     = $points;

	// Get WDS66 username
	$content['wernis_userid'] = getUserData('wernis_userid');
} elseif ((getRequestParameter('mode') == 'withdraw') && (getConfig('wernis_withdraw_active') == 'Y')) {
	// Prepare data for the template
	$content['points']        = getTotalPoints(getMemberId());
	$content['wernis_userid'] = '';

	// Fetch id
	$content['wernis_userid'] = getUserData('wernis_userid');
} else {
	// Invalid mode!
	loadTemplate('admin_settings_saved', false, getMaskedMessage('MEMBER_WERNIS_MODE_INVALID', getRequestParameter('mode')));
	return;
}

// Is the formular sent?
if ((isFormSent()) && (isGetRequestParameterSet('mode'))) {
	// Is the user id and password set?
	if (!isPostRequestParameterSet('wernis_userid')) {
		// Nothing entered in WDS66 user id
		loadTemplate('admin_settings_saved', false, '{--MEMBER_WERNIS_EMPTY_USERNAME--}');
	} elseif (!isPostRequestParameterSet('wds66_password')) {
		// Nothing entered in WDS66 password
		loadTemplate('admin_settings_saved', false, '{--MEMBER_WERNIS_EMPTY_PASSWORD--}');
	} elseif (!isPostRequestParameterSet('amount')) {
		// Nothing entered in amount
		loadTemplate('admin_settings_saved', false, '{--MEMBER_WERNIS_EMPTY_AMOUNT--}');
	} elseif (postRequestParameter('wernis_userid') != bigintval(postRequestParameter('wernis_userid'))) {
		// Only numbers in account id!
		loadTemplate('admin_settings_saved', false, '{--MEMBER_WERNIS_INVALID_USERNAME');
	} elseif (postRequestParameter('amount') != bigintval(postRequestParameter('amount'))) {
		// Only numbers in amount!
		loadTemplate('admin_settings_saved', false, '{--MEMBER_WERNIS_INVALID_AMOUNT--}');
	} else {
		// Check input data depending on the mode and execute the requested mode
		switch (getRequestParameter('mode')) {
			case 'withdraw': // Widthdraws WDS66 -> This exchange
				if (postRequestParameter('amount') < getConfig('wernis_min_withdraw')) {
					// Not enougth entered!
					loadTemplate('admin_settings_saved', false, '{--MEMBER_WERNIS_WITHDRAW_AMOUNT_SMALLER_MIN--}');
				} else {
					// All is fine here so do the withdraw
					$success = WERNIS_EXECUTE_WITHDRAW(postRequestParameter('wernis_userid'), md5(postRequestParameter('wds66_password')), postRequestParameter('amount'));
					if ($success === true) {
						// Add it to this amount
						addPointsDirectly('wernis_withdraw', getMemberId(), bigintval(postRequestParameter('amount')));

						// Update the user data as well..
						SQL_QUERY_ESC("UPDATE `{?_MYSQL_PREFIX?}_user_data` SET `wernis_userid`=%s WHERE `userid`=%s LIMIT 1",
							array(bigintval(postRequestParameter('wernis_userid')), getMemberId()), __FILE__, __LINE__);

						// All done!
						loadTemplate('admin_settings_saved', false, '{--MEMBER_WERNIS_WITHDRAW_DONE--}');
						return;
					} elseif ((GET_WERNIS_ERROR_CODE() == 'user_failed') || (GET_WERNIS_ERROR_CODE() == 'own_failed') || (GET_WERNIS_ERROR_CODE() == 'amount_failed')) {
						// Wrong login data
						loadTemplate('admin_settings_saved', false, GET_WERNIS_ERROR_MESSAGE());
					} else {
						// Something went wrong
						loadTemplate('admin_settings_saved', false, getMaskedMessage('MEMBER_WERNIS_WITHDRAW_FAILED', GET_WERNIS_ERROR_MESSAGE()));
					}
				}
				break;

			case 'payout': // Payout this exchange -> WDS66
				if (postRequestParameter('amount') < getConfig('wernis_min_payout')) {
					// Not enougth entered!
					loadTemplate('admin_settings_saved', false, '{--MEMBER_WERNIS_PAYOUT_AMOUNT_SMALLER_MIN--}');
				} elseif (postRequestParameter('amount') > $points) {
					// Not enougth points left!
					loadTemplate('admin_settings_saved', false, sprintf(getMessage('MEMBER_WERNIS_PAYOUT_POINTS_DEPLETED'), bigintval(postRequestParameter('amount')), bigintval($points)));
				} else {
					// All is fine here so do the withdraw
					$success = WERNIS_EXECUTE_PAYOUT(postRequestParameter('wernis_userid'), postRequestParameter('amount'));
					if ($success === true) {
						// Sub points
						subtractPoints('wernis_payout', getMemberId(), postRequestParameter('amount'));

						// Update WDS66 id
						SQL_QUERY_ESC("UPDATE `{?_MYSQL_PREFIX?}_user_data` SET `wernis_userid`=%s WHERE `userid`=%s LIMIT 1",
							array(bigintval(postRequestParameter('wernis_userid')), getMemberId()), __FILE__, __LINE__);

						// All done!
						loadTemplate('admin_settings_saved', false, '{--MEMBER_WERNIS_PAYOUT_DONE--}');
						return;
					} elseif ((GET_WERNIS_ERROR_CODE() == 'user_failed') || (GET_WERNIS_ERROR_CODE() == 'own_failed') || (GET_WERNIS_ERROR_CODE() == 'amount_failed') || (GET_WERNIS_ERROR_CODE() == 'api_amount_failed')) {
						// Wrong login data
						loadTemplate('admin_settings_saved', false, GET_WERNIS_ERROR_MESSAGE());
					} else {
						// Something went wrong
						loadTemplate('admin_settings_saved', false, getMaskedMessage('MEMBER_WERNIS_WITHDRAW_FAILED', GET_WERNIS_ERROR_MESSAGE()));
					}
				}
				break;

			default: // Invalid mode!
				logDebugMessage(__FILE__, __LINE__, sprintf("Invalid mode %s detected.", getRequestParameter('mode')));
				loadTemplate('admin_settings_saved', false, getMaskedMessage('MEMBER_WERNIS_MODE_INVALID', getRequestParameter('mode')));
				return;
		} // END - switch
	}
} // END - if

// Prepare mode for template name
$mode = sprintf("member_wernis_mode_%s", getRequestParameter('mode'));

// Load the template
loadTemplate($mode, false, $content);

// [EOF]
?>
